LANGUAGES = {u'ach': {u'English': u'Acholi', u'native': u'Acholi'},
 u'af': {u'English': u'Afrikaans', u'native': u'Afrikaans'},
 u'ak': {u'English': u'Akan', u'native': u'Akan'},
 u'am-et': {u'English': u'Amharic', u'native': u'\u12a0\u121b\u122d\u129b'},
 u'an': {u'English': u'Aragonese', u'native': u'aragon\xe9s'},
 u'ar': {u'English': u'Arabic', u'native': u'\u0639\u0631\u0628\u064a'},
 u'as': {u'English': u'Assamese',
         u'native': u'\u0985\u09b8\u09ae\u09c0\u09af\u09bc\u09be'},
 u'ast': {u'English': u'Asturian', u'native': u'Asturianu'},
 u'az': {u'English': u'Azerbaijani', u'native': u'Az\u0259rbaycanca'},
 u'be': {u'English': u'Belarusian',
         u'native': u'\u0411\u0435\u043b\u0430\u0440\u0443\u0441\u043a\u0430\u044f'},
 u'bg': {u'English': u'Bulgarian',
         u'native': u'\u0411\u044a\u043b\u0433\u0430\u0440\u0441\u043a\u0438'},
 u'bn-BD': {u'English': u'Bengali (Bangladesh)',
            u'native': u'\u09ac\u09be\u0982\u09b2\u09be (\u09ac\u09be\u0982\u09b2\u09be\u09a6\u09c7\u09b6)'},
 u'bn-IN': {u'English': u'Bengali (India)',
            u'native': u'\u09ac\u09be\u0982\u09b2\u09be (\u09ad\u09be\u09b0\u09a4)'},
 u'br': {u'English': u'Breton', u'native': u'Brezhoneg'},
 u'bs': {u'English': u'Bosnian', u'native': u'Bosanski'},
 u'ca': {u'English': u'Catalan', u'native': u'Catal\xe0'},
 u'ca-valencia': {u'English': u'Catalan (Valencian)',
                  u'native': u'catal\xe0 (valenci\xe0)'},
 u'cs': {u'English': u'Czech', u'native': u'\u010ce\u0161tina'},
 u'csb': {u'English': u'Kashubian', u'native': u'Kasz\xebbsczi'},
 u'cy': {u'English': u'Welsh', u'native': u'Cymraeg'},
 u'da': {u'English': u'Danish', u'native': u'Dansk'},
 u'dbg': {u'English': u'Debug Robot',
          u'native': u'\u1e12\u1e17\u0180\u016d\u0260 \u0158\u01ff\u0180\u01ff\u0167'},
 u'de': {u'English': u'German', u'native': u'Deutsch'},
 u'de-AT': {u'English': u'German (Austria)',
            u'native': u'Deutsch (\xd6sterreich)'},
 u'de-CH': {u'English': u'German (Switzerland)',
            u'native': u'Deutsch (Schweiz)'},
 u'de-DE': {u'English': u'German (Germany)',
            u'native': u'Deutsch (Deutschland)'},
 u'dsb': {u'English': u'Lower Sorbian',
          u'native': u'Dolnoserb\u0161\u0107ina'},
 u'ee': {u'English': u'Ewe', u'native': u'\xc8\u028begbe'},
 u'el': {u'English': u'Greek',
         u'native': u'\u0395\u03bb\u03bb\u03b7\u03bd\u03b9\u03ba\u03ac'},
 u'en-AU': {u'English': u'English (Australian)',
            u'native': u'English (Australian)'},
 u'en-CA': {u'English': u'English (Canadian)',
            u'native': u'English (Canadian)'},
 u'en-GB': {u'English': u'English (British)', u'native': u'English (British)'},
 u'en-NZ': {u'English': u'English (New Zealand)',
            u'native': u'English (New Zealand)'},
 u'en-US': {u'English': u'English (US)', u'native': u'English (US)'},
 u'en-ZA': {u'English': u'English (South African)',
            u'native': u'English (South African)'},
 u'eo': {u'English': u'Esperanto', u'native': u'Esperanto'},
 u'es': {u'English': u'Spanish', u'native': u'Espa\xf1ol'},
 u'es-AR': {u'English': u'Spanish (Argentina)',
            u'native': u'Espa\xf1ol (de Argentina)'},
 u'es-CL': {u'English': u'Spanish (Chile)',
            u'native': u'Espa\xf1ol (de Chile)'},
 u'es-ES': {u'English': u'Spanish (Spain)',
            u'native': u'Espa\xf1ol (de Espa\xf1a)'},
 u'es-MX': {u'English': u'Spanish (Mexico)',
            u'native': u'Espa\xf1ol (de M\xe9xico)'},
 u'et': {u'English': u'Estonian', u'native': u'Eesti keel'},
 u'eu': {u'English': u'Basque', u'native': u'Euskara'},
 u'fa': {u'English': u'Persian', u'native': u'\u0641\u0627\u0631\u0633\u06cc'},
 u'ff': {u'English': u'Fulah', u'native': u'Pulaar-Fulfulde'},
 u'fi': {u'English': u'Finnish', u'native': u'suomi'},
 u'fj-FJ': {u'English': u'Fijian', u'native': u'Vosa vaka-Viti'},
 u'fr': {u'English': u'French', u'native': u'Fran\xe7ais'},
 u'fur-IT': {u'English': u'Friulian', u'native': u'Furlan'},
 u'fy-NL': {u'English': u'Frisian', u'native': u'Frysk'},
 u'ga': {u'English': u'Irish', u'native': u'Gaeilge'},
 u'ga-IE': {u'English': u'Irish', u'native': u'Gaeilge'},
 u'gd': {u'English': u'Gaelic (Scotland)', u'native': u'G\xe0idhlig'},
 u'gl': {u'English': u'Galician', u'native': u'Galego'},
 u'gu': {u'English': u'Gujarati',
         u'native': u'\u0a97\u0ac1\u0a9c\u0ab0\u0abe\u0aa4\u0ac0'},
 u'gu-IN': {u'English': u'Gujarati (India)',
            u'native': u'\u0a97\u0ac1\u0a9c\u0ab0\u0abe\u0aa4\u0ac0 (\u0aad\u0abe\u0ab0\u0aa4)'},
 u'he': {u'English': u'Hebrew', u'native': u'\u05e2\u05d1\u05e8\u05d9\u05ea'},
 u'hi': {u'English': u'Hindi',
         u'native': u'\u0939\u093f\u0928\u094d\u0926\u0940'},
 u'hi-IN': {u'English': u'Hindi (India)',
            u'native': u'\u0939\u093f\u0928\u094d\u0926\u0940 (\u092d\u093e\u0930\u0924)'},
 u'hr': {u'English': u'Croatian', u'native': u'Hrvatski'},
 u'hsb': {u'English': u'Upper Sorbian', u'native': u'Hornjoserbsce'},
 u'hu': {u'English': u'Hungarian', u'native': u'magyar'},
 u'hy-AM': {u'English': u'Armenian',
            u'native': u'\u0540\u0561\u0575\u0565\u0580\u0565\u0576'},
 u'id': {u'English': u'Indonesian', u'native': u'Bahasa Indonesia'},
 u'is': {u'English': u'Icelandic', u'native': u'\xedslenska'},
 u'it': {u'English': u'Italian', u'native': u'Italiano'},
 u'ja': {u'English': u'Japanese', u'native': u'\u65e5\u672c\u8a9e'},
 u'ja-JP-mac': {u'English': u'Japanese', u'native': u'\u65e5\u672c\u8a9e'},
 u'ka': {u'English': u'Georgian',
         u'native': u'\u10e5\u10d0\u10e0\u10d7\u10e3\u10da\u10d8'},
 u'kk': {u'English': u'Kazakh', u'native': u'\u049a\u0430\u0437\u0430\u049b'},
 u'km': {u'English': u'Khmer', u'native': u'\u1781\u17d2\u1798\u17c2\u179a'},
 u'kn': {u'English': u'Kannada', u'native': u'\u0c95\u0ca8\u0ccd\u0ca8\u0ca1'},
 u'ko': {u'English': u'Korean', u'native': u'\ud55c\uad6d\uc5b4'},
 u'ku': {u'English': u'Kurdish', u'native': u'Kurd\xee'},
 u'la': {u'English': u'Latin', u'native': u'Latina'},
 u'lg': {u'English': u'Luganda', u'native': u'Luganda'},
 u'lij': {u'English': u'Ligurian', u'native': u'Ligure'},
 u'ln': {u'English': u'Lingala', u'native': u'Ling\xe1la'},
 u'lo': {u'English': u'Lao',
         u'native': u'\u0e9e\u0eb2\u0eaa\u0eb2\u0ea5\u0eb2\u0ea7'},
 u'lt': {u'English': u'Lithuanian', u'native': u'lietuvi\u0173 kalba'},
 u'lv': {u'English': u'Latvian', u'native': u'Latvie\u0161u'},
 u'mai': {u'English': u'Maithili',
          u'native': u'\u092e\u0948\u0925\u093f\u0932\u0940 \u09ae\u09c8\u09a5\u09bf\u09b2\u09c0'},
 u'mg': {u'English': u'Malagasy', u'native': u'Malagasy'},
 u'mi': {u'English': u'Maori (Aotearoa)', u'native': u'M\u0101ori (Aotearoa)'},
 u'mk': {u'English': u'Macedonian',
         u'native': u'\u041c\u0430\u043a\u0435\u0434\u043e\u043d\u0441\u043a\u0438'},
 u'ml': {u'English': u'Malayalam',
         u'native': u'\u0d2e\u0d32\u0d2f\u0d3e\u0d33\u0d02'},
 u'mn': {u'English': u'Mongolian',
         u'native': u'\u041c\u043e\u043d\u0433\u043e\u043b'},
 u'mr': {u'English': u'Marathi', u'native': u'\u092e\u0930\u093e\u0920\u0940'},
 u'ms': {u'English': u'Malay', u'native': u'Melayu'},
 u'my': {u'English': u'Burmese',
         u'native': u'\u1019\u103c\u1014\u103a\u1019\u102c\u1018\u102c\u101e\u102c'},
 u'nb-NO': {u'English': u'Norwegian (Bokm\xe5l)',
            u'native': u'Norsk bokm\xe5l'},
 u'ne-NP': {u'English': u'Nepali',
            u'native': u'\u0928\u0947\u092a\u093e\u0932\u0940'},
 u'nl': {u'English': u'Dutch', u'native': u'Nederlands'},
 u'nn-NO': {u'English': u'Norwegian (Nynorsk)', u'native': u'Norsk nynorsk'},
 u'nr': {u'English': u'Ndebele, South', u'native': u'isiNdebele'},
 u'nso': {u'English': u'Northern Sotho', u'native': u'Sepedi'},
 u'oc': {u'English': u'Occitan (Lengadocian)',
         u'native': u'occitan (lengadocian)'},
 u'or': {u'English': u'Oriya', u'native': u'\u0b13\u0b21\u0b3c\u0b3f\u0b06'},
 u'pa': {u'English': u'Punjabi',
         u'native': u'\u0a2a\u0a70\u0a1c\u0a3e\u0a2c\u0a40'},
 u'pa-IN': {u'English': u'Punjabi (India)',
            u'native': u'\u0a2a\u0a70\u0a1c\u0a3e\u0a2c\u0a40 (\u0a2d\u0a3e\u0a30\u0a24)'},
 u'pl': {u'English': u'Polish', u'native': u'Polski'},
 u'pt-BR': {u'English': u'Portuguese (Brazilian)',
            u'native': u'Portugu\xeas (do\xa0Brasil)'},
 u'pt-PT': {u'English': u'Portuguese (Portugal)',
            u'native': u'Portugu\xeas (Europeu)'},
 u'rm': {u'English': u'Romansh', u'native': u'rumantsch'},
 u'ro': {u'English': u'Romanian', u'native': u'rom\xe2n\u0103'},
 u'ru': {u'English': u'Russian',
         u'native': u'\u0420\u0443\u0441\u0441\u043a\u0438\u0439'},
 u'rw': {u'English': u'Kinyarwanda', u'native': u'Ikinyarwanda'},
 u'sa': {u'English': u'Sanskrit',
         u'native': u'\u0938\u0902\u0938\u094d\u0915\u0943\u0924'},
 u'sah': {u'English': u'Sakha',
          u'native': u'\u0421\u0430\u0445\u0430\u043b\u044b\u044b'},
 u'si': {u'English': u'Sinhala', u'native': u'\u0dc3\u0dd2\u0d82\u0dc4\u0dbd'},
 u'sk': {u'English': u'Slovak', u'native': u'sloven\u010dina'},
 u'sl': {u'English': u'Slovenian', u'native': u'Sloven\u0161\u010dina'},
 u'son': {u'English': u'Songhai', u'native': u'So\u014bay'},
 u'sq': {u'English': u'Albanian', u'native': u'Shqip'},
 u'sr': {u'English': u'Serbian',
         u'native': u'\u0421\u0440\u043f\u0441\u043a\u0438'},
 u'sr-Cyrl': {u'English': u'Serbian',
              u'native': u'\u0421\u0440\u043f\u0441\u043a\u0438'},
 u'sr-Latn': {u'English': u'Serbian', u'native': u'Srpski'},
 u'ss': {u'English': u'Siswati', u'native': u'siSwati'},
 u'st': {u'English': u'Southern Sotho', u'native': u'Sesotho'},
 u'sv-SE': {u'English': u'Swedish', u'native': u'Svenska'},
 u'sw': {u'English': u'Swahili', u'native': u'Kiswahili'},
 u'ta': {u'English': u'Tamil', u'native': u'\u0ba4\u0bae\u0bbf\u0bb4\u0bcd'},
 u'ta-IN': {u'English': u'Tamil (India)',
            u'native': u'\u0ba4\u0bae\u0bbf\u0bb4\u0bcd (\u0b87\u0ba8\u0bcd\u0ba4\u0bbf\u0baf\u0bbe)'},
 u'ta-LK': {u'English': u'Tamil (Sri Lanka)',
            u'native': u'\u0ba4\u0bae\u0bbf\u0bb4\u0bcd (\u0b87\u0bb2\u0b99\u0bcd\u0b95\u0bc8)'},
 u'te': {u'English': u'Telugu',
         u'native': u'\u0c24\u0c46\u0c32\u0c41\u0c17\u0c41'},
 u'th': {u'English': u'Thai', u'native': u'\u0e44\u0e17\u0e22'},
 u'tn': {u'English': u'Tswana', u'native': u'Setswana'},
 u'tr': {u'English': u'Turkish', u'native': u'T\xfcrk\xe7e'},
 u'ts': {u'English': u'Tsonga', u'native': u'Xitsonga'},
 u'tt-RU': {u'English': u'Tatar', u'native': u'Tatar\xe7a'},
 u'uk': {u'English': u'Ukrainian',
         u'native': u'\u0423\u043a\u0440\u0430\u0457\u043d\u0441\u044c\u043a\u0430'},
 u'ur': {u'English': u'Urdu', u'native': u'\u0627\u064f\u0631\u062f\u0648'},
 u'uz': {u'English': u'Uzbek', u'native': u'O\u02bbzbek tili'},
 u've': {u'English': u'Venda', u'native': u'Tshiven\u1e13a'},
 u'vi': {u'English': u'Vietnamese', u'native': u'Ti\u1ebfng Vi\u1ec7t'},
 u'wo': {u'English': u'Wolof', u'native': u'Wolof'},
 u'x-testing': {u'English': u'Testing',
                u'native': u'\u0166\u1e17\u015f\u0167\u012b\u019e\u0260'},
 u'xh': {u'English': u'Xhosa', u'native': u'isiXhosa'},
 u'zh-CN': {u'English': u'Chinese (Simplified)',
            u'native': u'\u4e2d\u6587 (\u7b80\u4f53)'},
 u'zh-TW': {u'English': u'Chinese (Traditional)',
            u'native': u'\u6b63\u9ad4\u4e2d\u6587 (\u7e41\u9ad4)'},
 u'zu': {u'English': u'Zulu', u'native': u'isiZulu'}}